==> nextcloud-19.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/mn.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Үйлдлүүд",
    "An error occurred while loading activities" : "Үйлдлүүдийг ачааллахад алдаа гарлаа",
    "No activity yet" : "Одоохондоо ямар ч үйлдэл алга",
    "Load more activities" : "Бусад үйлдлүүдийг ачаалах",
    "Copied!" : "Хуулав!",
    "Not supported!" : "Дэмжихгүй!",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "{name} (invisible)" : "{name} (үл харагдах)",
    "{name} (restricted)" : "{name} (хязгаартай)",
    "Home" : "Нүүр",
    "in {path}" : "{path} -д",
    "This stream will show events like additions, changes & shares" : "Файл нэмэх, өөрчлөх болон түгээх гэх мэт үйл явдлууд энд харагдана",
    "There are no events for this filter" : "Энд ямар нэг үйл явдал алга",
    "Today" : "Өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Your feed URL is invalid" : "Таны URL хүчин төгөлдөр бус байна",
    "Your settings have been updated." : "Таны тохиргоог шинэчлэв",
    "Settings have been updated." : "Тохиргоог шинэчлэв",
    "All activities" : "Бүх үйлдэлүүд",
    "By others" : "Бусдын үйлдлүүд",
    "By you" : "Таны үйлдлүүд",
    "Hello %s" : "Сайн байна уу, %s",
    "Hello %s," : "Сайн байна уу, %s,",
    "Mail" : "Цахим шуудан",
    "Activity feed" : "Үйлдлүүдйн тэжээл",
    "Notifications" : "Мэдэгдэл",
    "You need to set up your email address before you can receive notification emails." : "Та цахим шуудангаар мэдэгдэл хүлээн авахын тулд цахим шуудангаа тохируулна уу?",
    "Hourly" : "Цаг бүр",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Settings" : "Тохиргоо",
    "Enable RSS feed" : "RSS feed идэвхжүүлэх",
    "Stream" : "Урсгал",
    "Configure the default activity settings for new users." : "Шинэ хэрэглэгчдийн \"Үйлдлүүд\" хэсгийн анхдагч тохиргоог тохируулах",
    "List your own actions in the stream" : "\"Үйлдлүүд\" апп-д өөрийн үйл ажиллагааг харуулах",
    "Notify about your own actions via email" : "Цахим шуудангаар өөрийн үйл ажиллагааны тухай мэдэгдэл хүлээн авах",
    "Send emails:" : "Цахим шуудан илгээх:",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Та цахим шуудангаар ямар үйлдлийн талаар мэдээлэл авахыг хүсэж байгаа болон \"Үйлдлүүд\" хэсэгт ямар үйлдэл харуулахыг хүсэж байгаагаа сонгоно уу."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-20.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/activity/l10n/mn.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Үйлдлүүд",
    "An error occurred while loading activities" : "Үйлдлүүдийг ачааллахад алдаа гарлаа",
    "No activity yet" : "Одоохондоо ямар ч үйлдэл алга",
    "Load more activities" : "Бусад үйлдлүүдийг ачаалах",
    "Copied!" : "Хуулав!",
    "Not supported!" : "Дэмжихгүй!",
    "Press ⌘-C to copy." : "Хуулахын тулд ⌘-C дарна уу.",
    "Press Ctrl-C to copy." : "Хуулахын тулд Ctrl-C дарна уу.",
    "{name} (invisible)" : "{name} (үл харагдах)",
    "{name} (restricted)" : "{name} (хязгаартай)",
    "Home" : "Нүүр",
    "in {path}" : "{path} -д",
    "This stream will show events like additions, changes & shares" : "Файл нэмэх, өөрчлөх болон түгээх гэх мэт үйл явдлууд энд харагдана",
    "There are no events for this filter" : "Энд ямар нэг үйл явдал алга",
    "Today" : "Өнөөдөр",
    "Yesterday" : "Өчигдөр",
    "Open file" : "Файл онгойлгох",
    "Your feed URL is invalid" : "Таны URL хүчин төгөлдөр бус байна",
    "Your settings have been updated." : "Таны тохиргоог шинэчлэв",
    "Settings have been updated." : "Тохиргоог шинэчлэв",
    "All activities" : "Бүх үйлдэлүүд",
    "By others" : "Бусдын үйлдлүүд",
    "By you" : "Таны үйлдлүүд",
    "Hello %s" : "Сайн байна уу, %s",
    "Hello %s," : "Сайн байна уу, %s,",
    "Mail" : "Цахим шуудан",
    "Activity feed" : "Үйлдлүүдйн тэжээл",
    "Notifications" : "Мэдэгдэл",
    "Enable notification emails" : "Эмэйл мэдэгдлийг идэвхжүүлэх",
    "Default settings" : "Өгөгдмөл тохиргоо",
    "You need to set up your email address before you can receive notification emails." : "Та цахим шуудангаар мэдэгдэл хүлээн авахын тулд цахим шуудангаа тохируулна уу?",
    "Send notification emails:" : "Эмэйлээр мэдэгдэл авах ",
    "Hourly" : "Цаг бүр",
    "Daily" : "Өдөр бүр",
    "Weekly" : "Долоо хоног бүр",
    "Settings" : "Тохиргоо",
    "Enable RSS feed" : "RSS feed идэвхжүүлэх",
    "Stream" : "Урсгал",
    "Configure the default activity settings for new users." : "Шинэ хэрэглэгчдийн \"Үйлдлүүд\" хэсгийн анхдагч тохиргоог тохируулах",
    "List your own actions in the stream" : "\"Үйлдлүүд\" апп-д өөрийн үйл ажиллагааг харуулах",
    "Notify about your own actions via email" : "Цахим шуудангаар өөрийн үйл ажиллагааны тухай мэдэгдэл хүлээн авах",
    "Send emails:" : "Цахим шуудан илгээх:",
    "Choose for which activities you want to get an email notification, and which should show up in the activity app stream." : "Та цахим шуудангаар ямар үйлдлийн талаар мэдээлэл авахыг хүсэж байгаа болон \"Үйлдлүүд\" хэсэгт ямар үйлдэл харуулахыг хүсэж байгаагаа сонгоно уу."
},
"nplurals=2; plural=(n != 1);");
